/*
 * string.h - string and memory operations interface file
 *
 * Started 30/8/89 Alex G. Kiernan, based on Lattice source
 *
 * Copyright (c) 1989 HiSoft and Lattice, Inc.
 */
 
#ifndef _STRING_H
#define _STRING_H

#ifndef	_SIZE_T
#define	_SIZE_T
typedef unsigned long int size_t;
#endif

extern char _SLASH;		/* path separator character */

/*
 *
 * External definitions for string services
 *
 */
char *strcat(char *, const char *);
char *strchr(const char *, int);
int strcmp(const char *, const char *);
char *strcpy(char *, const char *);
size_t strcspn(const char *, const char *);
size_t strspn(const char *, const char *);
size_t strlen(const char *);
char *strncat(char *, const char *, size_t);
int strncmp(const char *, const char *, size_t);
char *strncpy(char *, const char *, size_t);
char *strpbrk(const char *, const char *);
char *strrchr(const char *, int);
char *strstr(const char *, const char *);
char *strtok(char *, const char *);
char *strerror(int);
int strcoll(const char *, const char *);
size_t strxfrm(char *, const char *, size_t);

size_t __builtin_strlen(const char *);
char *__builtin_strcpy(char *, const char *);
int __builtin_strcmp(const char *, const char *);

#define strlen(x)	__builtin_strlen(x)
#define strcpy(x,y)	__builtin_strcpy(x,y)
#define strcmp(x,y)	__builtin_strcmp(x,y)

#if !defined __STDC__ || __STDC__ != 1

size_t stcarg(const char *, const char *);
size_t stccpy(char *to, const char *from, size_t length);
char *stpcpy(char *, const char *);
char *strdup(const char *);
void strins(char *, const char *);
char *strnset(char *, int, size_t);
char *strrev(char *);
size_t stcis(const char *, const char *);
size_t stcisn(const char *, const char *);
size_t stcpm(const char *, const char *, char **);
size_t stcpma(const char *, const char *);
char *stpblk(const char *);
char *stpbrk(const char *, const char *);
char *stpchr(const char *, int);
char *stpsym(const char *, char *, size_t);
char *stpchrn(const char *, int);
char *stptok(const char *, char *, size_t, const char *);
long strbpl(char **, size_t, const char *);

int stcgfe(char *, char *);
int stcgfn(char *, char *);
int stcd_i(const char *, int *);
int stcd_l(const char *, long *);
int stch_i(const char *, int *);
int stch_l(const char *, long *);
int stci_d(const char *, int);
int stci_h(const char *, int);
int stci_o(const char *, int);
int stcl_d(const char *, long);
int stcl_h(const char *, long);
int stcl_o(const char *, long);
int stco_i(const char *, int *);
int stco_l(const char *, long *);
int stcsma(char *, char *);
int stcu_d(char *, unsigned);
int stcul_d(char *, unsigned long);

size_t stclen(const char *);
#define stclen(a) strlen(a)

char *stpdate(char *, int, char *);
char *stptime(char *, int, char *);

int strmid(const char *, char *, size_t, size_t);
char *strlwr(char *);
void strmfe(char *, const char *, const char *);
void strmfn(char *, const char *, const char *, const char *, const char *);
void strmfp(char *, const char *, const char *);
int stcgfp(char *, const char *);

int strnicmp(const char *, const char *, size_t);
int stricmp(const char *, const char *);

char *strset(char *, int);
void strsfn(const char *, char *, char *, char *, char *);
char *strupr(char *);
int stspfp(char *, int *);
void strsrt(char *[], size_t);


#define strcmpi stricmp		/* For Microsoft compatibility */

#endif
/*
 *
 * External definitions for memory block services
 *
 */
void *memchr(const void *, int, size_t);
int memcmp(const void *, const void *, size_t);
void *memcpy(void *, const void *, size_t);
void *memmove(void *, const void *, size_t);
void *memset(void *, int, size_t);

void *__builtin_memset(void *, int, size_t);
int __builtin_memcmp(const void *, const void *, size_t);
void *__builtin_memcpy(void *, const void *, size_t);

#define memset(x,y,z)	__builtin_memset(x,y,z)
#define memcmp(x,y,z)	__builtin_memcmp(x,y,z)
#define memcpy(x,y,z)	__builtin_memcpy(x,y,z)

#if !defined __STDC__ || __STDC__ != 1

void *memccpy(void *, const void *, int, size_t);
void *memswp(void *, void *, size_t);
void *memrep(void *, void *, size_t, size_t);

void setmem(void *, unsigned, int);
void movmem(void *, void *, unsigned);
void repmem(void *, void *, unsigned, unsigned);
void swmem(void *, void *, unsigned);
#endif

#define	NULL	((void *)0)

#endif
